'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_occlusion_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_occlusion_query',error_checker=_errors._error_checker)
GL_CURRENT_QUERY_ARB=_C('GL_CURRENT_QUERY_ARB',0x8865)
GL_QUERY_COUNTER_BITS_ARB=_C('GL_QUERY_COUNTER_BITS_ARB',0x8864)
GL_QUERY_RESULT_ARB=_C('GL_QUERY_RESULT_ARB',0x8866)
GL_QUERY_RESULT_AVAILABLE_ARB=_C('GL_QUERY_RESULT_AVAILABLE_ARB',0x8867)
GL_SAMPLES_PASSED_ARB=_C('GL_SAMPLES_PASSED_ARB',0x8914)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBeginQueryARB(target,id):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteQueriesARB(n,ids):pass
@_f
@_p.types(None,_cs.GLenum)
def glEndQueryARB(target):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenQueriesARB(n,ids):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetQueryObjectivARB(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetQueryObjectuivARB(id,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetQueryivARB(target,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsQueryARB(id):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_VERSION_WGL_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_VERSION_WGL_1_0',error_checker=_errors._error_checker)
WGL_FONT_LINES=_C('WGL_FONT_LINES',0)
WGL_FONT_POLYGONS=_C('WGL_FONT_POLYGONS',1)
WGL_SWAP_MAIN_PLANE=_C('WGL_SWAP_MAIN_PLANE',0x00000001)
WGL_SWAP_OVERLAY1=_C('WGL_SWAP_OVERLAY1',0x00000002)
WGL_SWAP_OVERLAY10=_C('WGL_SWAP_OVERLAY10',0x00000400)
WGL_SWAP_OVERLAY11=_C('WGL_SWAP_OVERLAY11',0x00000800)
WGL_SWAP_OVERLAY12=_C('WGL_SWAP_OVERLAY12',0x00001000)
WGL_SWAP_OVERLAY13=_C('WGL_SWAP_OVERLAY13',0x00002000)
WGL_SWAP_OVERLAY14=_C('WGL_SWAP_OVERLAY14',0x00004000)
WGL_SWAP_OVERLAY15=_C('WGL_SWAP_OVERLAY15',0x00008000)
WGL_SWAP_OVERLAY2=_C('WGL_SWAP_OVERLAY2',0x00000004)
WGL_SWAP_OVERLAY3=_C('WGL_SWAP_OVERLAY3',0x00000008)
WGL_SWAP_OVERLAY4=_C('WGL_SWAP_OVERLAY4',0x00000010)
WGL_SWAP_OVERLAY5=_C('WGL_SWAP_OVERLAY5',0x00000020)
WGL_SWAP_OVERLAY6=_C('WGL_SWAP_OVERLAY6',0x00000040)
WGL_SWAP_OVERLAY7=_C('WGL_SWAP_OVERLAY7',0x00000080)
WGL_SWAP_OVERLAY8=_C('WGL_SWAP_OVERLAY8',0x00000100)
WGL_SWAP_OVERLAY9=_C('WGL_SWAP_OVERLAY9',0x00000200)
WGL_SWAP_UNDERLAY1=_C('WGL_SWAP_UNDERLAY1',0x00010000)
WGL_SWAP_UNDERLAY10=_C('WGL_SWAP_UNDERLAY10',0x02000000)
WGL_SWAP_UNDERLAY11=_C('WGL_SWAP_UNDERLAY11',0x04000000)
WGL_SWAP_UNDERLAY12=_C('WGL_SWAP_UNDERLAY12',0x08000000)
WGL_SWAP_UNDERLAY13=_C('WGL_SWAP_UNDERLAY13',0x10000000)
WGL_SWAP_UNDERLAY14=_C('WGL_SWAP_UNDERLAY14',0x20000000)
WGL_SWAP_UNDERLAY15=_C('WGL_SWAP_UNDERLAY15',0x40000000)
WGL_SWAP_UNDERLAY2=_C('WGL_SWAP_UNDERLAY2',0x00020000)
WGL_SWAP_UNDERLAY3=_C('WGL_SWAP_UNDERLAY3',0x00040000)
WGL_SWAP_UNDERLAY4=_C('WGL_SWAP_UNDERLAY4',0x00080000)
WGL_SWAP_UNDERLAY5=_C('WGL_SWAP_UNDERLAY5',0x00100000)
WGL_SWAP_UNDERLAY6=_C('WGL_SWAP_UNDERLAY6',0x00200000)
WGL_SWAP_UNDERLAY7=_C('WGL_SWAP_UNDERLAY7',0x00400000)
WGL_SWAP_UNDERLAY8=_C('WGL_SWAP_UNDERLAY8',0x00800000)
WGL_SWAP_UNDERLAY9=_C('WGL_SWAP_UNDERLAY9',0x01000000)
@_f
@_p.types(_cs.c_int,_cs.HDC,ctypes.POINTER(_cs.PIXELFORMATDESCRIPTOR))
def ChoosePixelFormat(hDc,pPfd):pass
@_f
@_p.types(_cs.c_int,_cs.HDC,_cs.c_int,_cs.UINT,ctypes.POINTER(_cs.PIXELFORMATDESCRIPTOR))
def DescribePixelFormat(hdc,ipfd,cjpfd,ppfd):pass
@_f
@_p.types(_cs.UINT,_cs.HENHMETAFILE,ctypes.POINTER(_cs.PIXELFORMATDESCRIPTOR))
def GetEnhMetaFilePixelFormat(hemf,ppfd):pass
@_f
@_p.types(_cs.c_int,_cs.HDC)
def GetPixelFormat(hdc):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.PIXELFORMATDESCRIPTOR))
def SetPixelFormat(hdc,ipfd,ppfd):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC)
def SwapBuffers(hdc):pass
@_f
@_p.types(_cs.BOOL,_cs.HGLRC,_cs.HGLRC,_cs.UINT)
def wglCopyContext(hglrcSrc,hglrcDst,mask):pass
@_f
@_p.types(_cs.HGLRC,_cs.HDC)
def wglCreateContext(hDc):pass
@_f
@_p.types(_cs.HGLRC,_cs.HDC,_cs.c_int)
def wglCreateLayerContext(hDc,level):pass
@_f
@_p.types(_cs.BOOL,_cs.HGLRC)
def wglDeleteContext(oldContext):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,_cs.c_int,_cs.UINT,ctypes.POINTER(_cs.LAYERPLANEDESCRIPTOR))
def wglDescribeLayerPlane(hDc,pixelFormat,layerPlane,nBytes,plpd):pass
@_f
@_p.types(_cs.HGLRC,)
def wglGetCurrentContext():pass
@_f
@_p.types(_cs.HDC,)
def wglGetCurrentDC():pass
@_f
@_p.types(_cs.c_int,_cs.HDC,_cs.c_int,_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.COLORREF))
def wglGetLayerPaletteEntries(hdc,iLayerPlane,iStart,cEntries,pcr):pass
@_f
@_p.types(_cs.PROC,_cs.LPCSTR)
def wglGetProcAddress(lpszProc):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.HGLRC)
def wglMakeCurrent(hDc,newContext):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,_cs.BOOL)
def wglRealizeLayerPalette(hdc,iLayerPlane,bRealize):pass
@_f
@_p.types(_cs.c_int,_cs.HDC,_cs.c_int,_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.COLORREF))
def wglSetLayerPaletteEntries(hdc,iLayerPlane,iStart,cEntries,pcr):pass
@_f
@_p.types(_cs.BOOL,_cs.HGLRC,_cs.HGLRC)
def wglShareLists(hrcSrvShare,hrcSrvSource):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.UINT)
def wglSwapLayerBuffers(hdc,fuFlags):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD)
def wglUseFontBitmaps(hDC,first,count,listBase):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD)
def wglUseFontBitmapsA(hDC,first,count,listBase):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD)
def wglUseFontBitmapsW(hDC,first,count,listBase):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD,_cs.FLOAT,_cs.FLOAT,_cs.c_int,_cs.LPGLYPHMETRICSFLOAT)
def wglUseFontOutlines(hDC,first,count,listBase,deviation,extrusion,format,lpgmf):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD,_cs.FLOAT,_cs.FLOAT,_cs.c_int,_cs.LPGLYPHMETRICSFLOAT)
def wglUseFontOutlinesA(hDC,first,count,listBase,deviation,extrusion,format,lpgmf):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.DWORD,_cs.DWORD,_cs.DWORD,_cs.FLOAT,_cs.FLOAT,_cs.c_int,_cs.LPGLYPHMETRICSFLOAT)
def wglUseFontOutlinesW(hDC,first,count,listBase,deviation,extrusion,format,lpgmf):pass



'''OpenGL extension SUN.slice_accum

This module customises the behaviour of the 
OpenGL.raw.GL.SUN.slice_accum to provide a more 
Python-friendly API

Overview (from the spec)
	
	
	This extension defines a new accumulation operation which enables the accumulation
	buffer to be used for alpha compositing. This enables higher precision alpha
	blending than what can be accomplished using the blend operation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SUN/slice_accum.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SUN.slice_accum import *
from OpenGL.raw.GL.SUN.slice_accum import _EXTENSION_NAME

def glInitSliceAccumSUN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_viewport_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_viewport_array',error_checker=_errors._error_checker)
GL_DEPTH_RANGE=_C('GL_DEPTH_RANGE',0x0B70)
GL_FIRST_VERTEX_CONVENTION=_C('GL_FIRST_VERTEX_CONVENTION',0x8E4D)
GL_LAST_VERTEX_CONVENTION=_C('GL_LAST_VERTEX_CONVENTION',0x8E4E)
GL_LAYER_PROVOKING_VERTEX=_C('GL_LAYER_PROVOKING_VERTEX',0x825E)
GL_MAX_VIEWPORTS=_C('GL_MAX_VIEWPORTS',0x825B)
GL_PROVOKING_VERTEX=_C('GL_PROVOKING_VERTEX',0x8E4F)
GL_SCISSOR_BOX=_C('GL_SCISSOR_BOX',0x0C10)
GL_SCISSOR_TEST=_C('GL_SCISSOR_TEST',0x0C11)
GL_UNDEFINED_VERTEX=_C('GL_UNDEFINED_VERTEX',0x8260)
GL_VIEWPORT=_C('GL_VIEWPORT',0x0BA2)
GL_VIEWPORT_BOUNDS_RANGE=_C('GL_VIEWPORT_BOUNDS_RANGE',0x825D)
GL_VIEWPORT_INDEX_PROVOKING_VERTEX=_C('GL_VIEWPORT_INDEX_PROVOKING_VERTEX',0x825F)
GL_VIEWPORT_SUBPIXEL_BITS=_C('GL_VIEWPORT_SUBPIXEL_BITS',0x825C)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glDepthRangeArrayv(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble)
def glDepthRangeIndexed(index,n,f):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glGetDoublei_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetFloati_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLintArray)
def glScissorArrayv(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissorIndexed(index,left,bottom,width,height):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glScissorIndexedv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glViewportArrayv(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glViewportIndexedf(index,x,y,w,h):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glViewportIndexedfv(index,v):pass



'''OpenGL extension EXT.texture3D

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture3D to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines 3-dimensional texture mapping.  In order to
	define a 3D texture image conveniently, this extension also defines the
	in-memory formats for 3D images, and adds pixel storage modes to support
	them.
	
	One important application of 3D textures is rendering volumes of image
	data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture3D.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture3D import *
from OpenGL.raw.GL.EXT.texture3D import _EXTENSION_NAME

def glInitTexture3DEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexImage3DEXT.pixels size not checked against 'format,type,width,height,depth'
glTexImage3DEXT=wrapper.wrapper(glTexImage3DEXT).setInputArraySize(
    'pixels', None
)
# INPUT glTexSubImage3DEXT.pixels size not checked against 'format,type,width,height,depth'
glTexSubImage3DEXT=wrapper.wrapper(glTexSubImage3DEXT).setInputArraySize(
    'pixels', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.shader_storage_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.NV.shader_storage_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides assembly language support for shader storage
	buffers (from the ARB_shader_storage_buffer_object extension) for all
	program types supported by NV_gpu_program5, including compute programs
	added by the NV_compute_program5 extension.
	
	Assembly programs using this extension can read and write to the memory of
	buffer objects bound to the binding points provided by
	ARB_shader_storage_buffer_object.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shader_storage_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.shader_storage_buffer_object import *
from OpenGL.raw.GL.NV.shader_storage_buffer_object import _EXTENSION_NAME

def glInitShaderStorageBufferObjectNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.parameter_buffer_object2

This module customises the behaviour of the 
OpenGL.raw.GL.NV.parameter_buffer_object2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on the NV_parameter_buffer_object extension to
	provide additional flexibility in sourcing data from buffer objects.  
	
	The original NV_parameter_buffer_object (PaBO) extension provided the
	ability to bind buffer objects to a set of numbered binding points and
	access them in assembly programs as though they were arrays of 32-bit
	scalars (via the BUFFER variable type) or arrays of four-component vectors
	with 32-bit scalar components (via the BUFFER4 variable type).  However,
	the functionality it provided had some significant limits on flexibility.
	Since any given buffer binding point could be used either as a BUFFER or
	BUFFER4, but not both, programs couldn't do both 32- and 128-bit fetches
	from a single binding point.  Additionally, No support was provided for
	8-, 16-, or 64-bit fetches, though they could be emulated using a larger
	loads, with bitfield operations and/or write masking to put components in
	the right places.  Indexing was supported, but strides were limited to 4-
	and 16-byte multiples, depending on whether BUFFER or BUFFER4 is used.
	
	This new extension provides the buffer variable declaration type CBUFFER
	to specify a buffer that is treated as an array of bytes, rather than an
	array of words or vectors.  The LDC instruction allows programs to extract
	a vector of data from a CBUFFER variable, using a size and component count
	specified in the opcode modifier.  1-, 2-, and 4-component fetches are
	supported.  The LDC instruction supports byte offsets using normal array
	indexing mechanisms; both run-time and immediate offsets are supported.
	Offsets used for a buffer object fetch are required to be aligned to the
	size of the fetch (1, 2, 4, 8, or 16 bytes).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/parameter_buffer_object2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.parameter_buffer_object2 import *
from OpenGL.raw.GL.NV.parameter_buffer_object2 import _EXTENSION_NAME

def glInitParameterBufferObject2NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.sync

This module customises the behaviour of the 
OpenGL.raw.GLES1.APPLE.sync to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/sync.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.APPLE.sync import *
from OpenGL.raw.GLES1.APPLE.sync import _EXTENSION_NAME

def glInitSyncAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetSyncivAPPLE.values size not checked against bufSize
glGetSyncivAPPLE=wrapper.wrapper(glGetSyncivAPPLE).setInputArraySize(
    'values', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.pixel_transform

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.pixel_transform to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides support for scaling, rotation, translation and
	shearing of two-dimensional pixel rectangles in the pixel rasterizer.
	The transformation is defined via a 4x4 matrix, where only those entries
	which apply as a 2D affine transformation will be accepted and used.
	These matrices can be manipulated using the same functions as the other 
	OpenGL matrix stacks.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/pixel_transform.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.pixel_transform import *
from OpenGL.raw.GL.EXT.pixel_transform import _EXTENSION_NAME

def glInitPixelTransformEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glPixelTransformParameterivEXT=wrapper.wrapper(glPixelTransformParameterivEXT).setInputArraySize(
    'params', 1
)
glPixelTransformParameterfvEXT=wrapper.wrapper(glPixelTransformParameterfvEXT).setInputArraySize(
    'params', 1
)
glGetPixelTransformParameterivEXT=wrapper.wrapper(glGetPixelTransformParameterivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetPixelTransformParameterfvEXT=wrapper.wrapper(glGetPixelTransformParameterfvEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.shader_storage_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_storage_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the ability for OpenGL shaders to perform random
	access reads, writes, and atomic memory operations on variables stored in
	a buffer object.  Application shader code can declare sets of variables
	(referred to as "buffer variables") arranged into interface blocks in a
	manner similar to that done with uniform blocks in OpenGL 3.1.  In both
	cases, the values of the variables declared in a given interface block are
	taken from a buffer object bound to a binding point associated with the
	block.  Buffer objects used in this extension are referred to as "shader
	storage buffers".  
	
	While the capability provided by this extension is similar to that
	provided by OpenGL 3.1 and ARB_uniform_buffer_object, there are several
	significant differences.  Most importantly, shader code is allowed to
	write to shader storage buffers, while uniform buffers are always
	read-only.  Shader storage buffers have a separate set of binding points,
	with different counts and size limits.  The maximum usable size for shader
	storage buffers is implementation-dependent, but its minimum value is
	substantially larger than the minimum for uniform buffers.  
	
	The ability to write to buffer objects creates the potential for multiple
	independent shader invocations to read and write the same underlying
	memory.  The same issue exists with the ARB_shader_image_load_store
	extension provided in OpenGL 4.2, which can write to texture objects and
	buffers.  In both cases, the specification makes few guarantees related to
	the relative order of memory reads and writes performed by the shader
	invocations.  For ARB_shader_image_load_store, the OpenGL API and shading
	language do provide some control over memory transactions; those
	mechanisms also affect reads and writes of shader storage buffers.  In the
	OpenGL API, the glMemoryBarrier() call can be used to ensure that certain
	memory operations related to commands issued prior the barrier complete
	before other operations related to commands issued after the barrier.
	Additionally, the shading language provides the memoryBarrier() function
	to control the relative order of memory accesses within individual shader
	invocations and provides various memory qualifiers controlling how the
	memory corresponding to individual variables is accessed.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_storage_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_storage_buffer_object import *
from OpenGL.raw.GL.ARB.shader_storage_buffer_object import _EXTENSION_NAME

def glInitShaderStorageBufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.occlusion_query_event

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.occlusion_query_event to provide a more 
Python-friendly API

Overview (from the spec)
	
	Occlusion queries provide a means to count the number of fragments that
	pass the depth and stencil tests and that may contribute to a rendered
	image. In unextended OpenGL, an occlusion query increments its
	samples-passed count whenever a sample passes both the stencil test and
	the depth test (if enabled). However, there is no way to count fragments
	that fail the stencil test, or pass the stencil test and then subsequently
	fail the depth test.
	
	This extension introduces the concept of occlusion query events and changes
	the concept of an occlusion query from counting passed fragments to counting
	fragments that generate any of a user-selectable set of events. Provided
	events include passing the depth test, and passing or failing the stencil
	test. For a given occlusion query object, counting of these events may be
	enabled or disabled, allowing any combination to be counted.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/occlusion_query_event.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.occlusion_query_event import *
from OpenGL.raw.GL.AMD.occlusion_query_event import _EXTENSION_NAME

def glInitOcclusionQueryEventAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_1_2

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_2 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_1_2 import *
from OpenGL.raw.GL.VERSION.GL_1_2 import _EXTENSION_NAME

def glInitGl12VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawRangeElements.indices size not checked against 'count,type'
glDrawRangeElements=wrapper.wrapper(glDrawRangeElements).setInputArraySize(
    'indices', None
)
# INPUT glTexImage3D.pixels size not checked against 'format,type,width,height,depth'
glTexImage3D=wrapper.wrapper(glTexImage3D).setInputArraySize(
    'pixels', None
)
# INPUT glTexSubImage3D.pixels size not checked against 'format,type,width,height,depth'
glTexSubImage3D=wrapper.wrapper(glTexSubImage3D).setInputArraySize(
    'pixels', None
)
### END AUTOGENERATED SECTION
from OpenGL.GL.ARB.imaging import *
from OpenGL.GL.VERSION.GL_1_2_images import *

GL_POINT_SIZE_GRANULARITY = GL_SMOOTH_POINT_SIZE_GRANULARITY # alias
GL_POINT_SIZE_RANGE = GL_SMOOTH_POINT_SIZE_RANGE # alias
GL_LINE_WIDTH_GRANULARITY = GL_SMOOTH_LINE_WIDTH_GRANULARITY # alias
GL_LINE_WIDTH_RANGE = GL_SMOOTH_LINE_WIDTH_RANGE # alias

glDrawRangeElements = wrapper.wrapper( glDrawRangeElements ).setPyConverter(
    'indices', arrays.AsArrayOfType( 'indices', 'type' ),
).setReturnValues(
    wrapper.returnPyArgument( 'indices' )
)





"""List of forward-compatible entry points for OpenGL 3.1

Taken from the list at:

    http://www.devklog.net/2008/08/23/forward-compatible-opengl-3-entry-points/
"""
records = """glActiveTexture
glAttachShader
glBeginConditionalRender
glBeginQuery
glBeginTransformFeedback
glBindAttribLocation
glBindBuffer
glBindBufferBase
glBindBufferRange
glBindFragDataLocation
glBindFramebuffer
glBindRenderbuffer
glBindTexture
glBindVertexArray
glBlendColor
glBlendEquation
glBlendEquationSeparate
glBlendFunc
glBlendFuncSeparate
glBlitFramebuffer
glBufferData
glBufferSubData
glCheckFramebufferStatus
glClampColor
glClear
glClearBuffer*
glClearColor
glClearDepth
glClearStencil
glClipPlane
glColorMask*
glCompileShader
glCompressedTexImage*
glCompressedTexSubImage*
glCopyPixels
glCopyTexImage*
glCopyTexSubImage*
glCreateProgram
glCreateShader
glCullFace
glDeleteBuffers
glDeleteFramebuffers
glDeleteProgram
glDeleteQueries
glDeleteRenderbuffers
glDeleteShader
glDeleteTextures
glDeleteVertexArrays
glDepthFunc
glDepthMask
glDepthRange
glDetachShader
glDisable
glDisableVertexAttribArray
glDrawArrays
glDrawBuffer
glDrawBuffers
glDrawElements
glDrawRangeElements
glEnable
glEnableVertexAttribArray
glEndConditionalRender
glEndQuery
glEndTransformFeedback
glFinish
glFlush
glFlushMappedBufferRange
glFramebufferRenderbuffer
glFramebufferTexture*
glFramebufferTextureLayer
glFrontFace
glGenBuffers
glGenerateMipmap
glGenFramebuffers
glGenQueries
glGenRenderbuffers
glGenTextures
glGenVertexArrays
glGetActiveAttrib
glGetActiveUniform
glGetAttachedShaders
glGetAttribLocation
glGetBooleanv
glGetBufferParameter*
glGetBufferPointer*
glGetBufferSubData
glGetClipPlane
glGetCompressedTexImage
glGetDoublev
glGetError
glGetFloatv
glGetFragDataLocation
glGetFramebufferAttachmentParameter*
glGetIntegerv
glGetProgram*
glGetProgramInfoLog
glGetQuery*
glGetQueryObject*
glGetRenderbufferParameter*
glGetShader*
glGetShaderInfoLog
glGetShaderSource
glGetString
glGetTexEnv*
glGetTexImage
glGetTexLevelParameter*
glGetTexParameter*
glGetTransformFeedbackVaryings
glGetUniform*
glGetUniformLocation
glGetVertexAttrib*
glGetVertexAttribIPointer*
glGetVertexAttribPointer*
glHint
glIsBuffer
glIsEnabled
glIsFramebuffer
glIsProgram
glIsQuery
glIsRenderbuffer
glIsShader
glIsTexture
glIsVertexArray
glLineWidth
glLinkProgram
glLogicOp
glMapBuffer
glMapBufferRange
glMultiDrawArrays
glMultiDrawElements
glPixelStore*
glPointParameter*
glPointSize
glPolygonMode
glReadBuffer
glReadPixels
glRenderbufferStorage
glRenderbufferStorageMultisample
glSampleCoverage
glScissor
glShadeModel
glShaderSource
glStencilFunc
glStencilFuncSeparate
glStencilMask
glStencilMaskSeparate
glStencilOp
glStencilOpSeparate
glTexEnv
glTexImage*
glTexParameter*
glTexSubImage*
glTransformFeedbackVaryings
glUniform1*
glUniform2*
glUniform3*
glUniform4*
glUniformMatrix2*
glUniformMatrix2x3*
glUniformMatrix2x4*
glUniformMatrix3*
glUniformMatrix3x2*
glUniformMatrix3x4*
glUniformMatrix4*
glUniformMatrix4x2*
glUniformMatrix4x3*
glUnmapBuffer
glUseProgram
glValidateProgram
glVertexAttrib1*
glVertexAttrib2*
glVertexAttrib3*
glVertexAttrib4*
glVertexAttrib4N*
glVertexAttribI*
glVertexAttribI4
glVertexAttribIPointer
glVertexAttribPointer
glViewport""".splitlines()
def deprecated( name ):
    for allowed in records:
        if name == allowed:
            return False 
        elif allowed.endswith( '*' ) and allowed.startswith(name[:len(allowed)-1]):
            return False 
    return True 


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_copy_image'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_copy_image',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glCopyImageSubData(srcName,srcTarget,srcLevel,srcX,srcY,srcZ,dstName,dstTarget,dstLevel,dstX,dstY,dstZ,srcWidth,srcHeight,srcDepth):pass



'''OpenGL extension SGIX.texture_scale_bias

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.texture_scale_bias to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds scale, bias, and clamp to [0, 1] operations to the 
	texture pipeline.
	These operations are applied to the filtered result of a texture lookup,
	before that result is used in the texture environment equations and
	before the texture color lookup table of SGI_texture_color_table, 
	if that extension exists.
	These operations are distinct from the scale, bias, and clamp operations
	that appear in the SGI_color_table extension, which are used to
	define a color lookup table.
	
	Scale and bias operations on texels can be used to better utilize the
	color resolution of a particular texture internal format (see EXT_texture).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/texture_scale_bias.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.texture_scale_bias import *
from OpenGL.raw.GL.SGIX.texture_scale_bias import _EXTENSION_NAME

def glInitTextureScaleBiasSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_gpu_program5'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_gpu_program5',error_checker=_errors._error_checker)
GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV=_C('GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV',0x8E5D)
GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV=_C('GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV',0x8E5C)
GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV=_C('GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV',0x8E5A)
GL_MAX_PROGRAM_SUBROUTINE_NUM_NV=_C('GL_MAX_PROGRAM_SUBROUTINE_NUM_NV',0x8F45)
GL_MAX_PROGRAM_SUBROUTINE_PARAMETERS_NV=_C('GL_MAX_PROGRAM_SUBROUTINE_PARAMETERS_NV',0x8F44)
GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV=_C('GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV',0x8E5F)
GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV=_C('GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV',0x8E5B)
GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV=_C('GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV',0x8E5E)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLuintArray)
def glGetProgramSubroutineParameteruivNV(target,index,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glProgramSubroutineParametersuivNV(target,count,params):pass



import ctypes
from OpenGL import _opaque
GLenum = ctypes.c_uint
GLboolean = ctypes.c_ubyte
GLsizei = ctypes.c_int
GLint = ctypes.c_int
OSMesaContext = _opaque.opaque_pointer_cls( 'OSMesaContext' )

__all__ = [
    'OSMesaContext',
]



'''OpenGL extension ARB.tessellation_shader

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.tessellation_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces new tessellation stages and two new shader types
	to the OpenGL primitive processing pipeline.  These pipeline stages
	operate on a new basic primitive type, called a patch.  A patch consists
	of a fixed-size collection of vertices, each with per-vertex attributes,
	plus a number of associated per-patch attributes.  Tessellation control
	shaders transform an input patch specified by the application, computing
	per-vertex and per-patch attributes for a new output patch.  A
	fixed-function tessellation primitive generator subdivides the patch, and
	tessellation evaluation shaders are used to compute the position and
	attributes of each vertex produced by the tessellator.
	
	When tessellation is active, it begins by running the optional
	tessellation control shader.  This shader consumes an input patch and
	produces a new fixed-size output patch.  The output patch consists of an
	array of vertices, and a set of per-patch attributes.  The per-patch
	attributes include tessellation levels that control how finely the patch
	will be tessellated.  For each patch processed, multiple tessellation
	control shader invocations are performed -- one per output patch vertex.
	Each tessellation control shader invocation writes all the attributes of
	its corresponding output patch vertex.  A tessellation control shader may
	also read the per-vertex outputs of other tessellation control shader
	invocations, as well as read and write shared per-patch outputs.  The
	tessellation control shader invocations for a single patch effectively run
	as a group.  A built-in barrier() function is provided to allow
	synchronization points where no shader invocation will continue until all
	shader invocations have reached the barrier.
	
	The tessellation primitive generator then decomposes a patch into a new
	set of primitives using the tessellation levels to determine how finely
	tessellated the output should be.  The primitive generator begins with
	either a triangle or a quad, and splits each outer edge of the primitive
	into a number of segments approximately equal to the corresponding element
	of the outer tessellation level array.  The interior of the primitive is
	tessellated according to elements of the inner tessellation level array.
	The primitive generator has three modes:  "triangles" and "quads" split a
	triangular or quad-shaped patch into a set of triangles that cover the
	original patch; "isolines" splits a quad-shaped patch into a set of line
	strips running across the patch horizontally.  Each vertex generated by
	the tessellation primitive generator is assigned a (u,v) or (u,v,w)
	coordinate indicating its relative location in the subdivided triangle or
	quad.
	
	For each vertex produced by the tessellation primitive generator, the
	tessellation evaluation shader is run to compute its position and other
	attributes of the vertex, using its (u,v) or (u,v,w) coordinate.  When
	computing final vertex attributes, the tessellation evaluation shader can
	also read the attributes of any of the vertices of the patch written by
	the tessellation control shader.  Tessellation evaluation shader
	invocations are completely independent, although all invocations for a
	single patch share the same collection of input vertices and per-patch
	attributes.
	
	The tessellator operates on vertices after they have been transformed by a
	vertex shader.  The primitives generated by the tessellator are passed
	further down the OpenGL pipeline, where they can be used as inputs to
	geometry shaders, transform feedback, and the rasterizer.
	
	The tessellation control and evaluation shaders are both optional.  If
	neither shader type is present, the tessellation stage has no effect.  If
	no tessellation control shader is present, the input patch provided by the
	application is passed directly to the tessellation primitive generator,
	and a set of default tessellation level parameters is used to control
	primitive generation.  In this extension, patches may not be passed beyond
	the tessellation evaluation shader, and an error is generated if an
	application provides patches and the current program object contains no
	tessellation evaluation shader.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/tessellation_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.tessellation_shader import *
from OpenGL.raw.GL.ARB.tessellation_shader import _EXTENSION_NAME

def glInitTessellationShaderARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPatchParameterfv.values size not checked against 'pname'
glPatchParameterfv=wrapper.wrapper(glPatchParameterfv).setInputArraySize(
    'values', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_PGI_misc_hints'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_PGI_misc_hints',error_checker=_errors._error_checker)
GL_ALLOW_DRAW_FRG_HINT_PGI=_C('GL_ALLOW_DRAW_FRG_HINT_PGI',0x1A210)
GL_ALLOW_DRAW_MEM_HINT_PGI=_C('GL_ALLOW_DRAW_MEM_HINT_PGI',0x1A211)
GL_ALLOW_DRAW_OBJ_HINT_PGI=_C('GL_ALLOW_DRAW_OBJ_HINT_PGI',0x1A20E)
GL_ALLOW_DRAW_WIN_HINT_PGI=_C('GL_ALLOW_DRAW_WIN_HINT_PGI',0x1A20F)
GL_ALWAYS_FAST_HINT_PGI=_C('GL_ALWAYS_FAST_HINT_PGI',0x1A20C)
GL_ALWAYS_SOFT_HINT_PGI=_C('GL_ALWAYS_SOFT_HINT_PGI',0x1A20D)
GL_BACK_NORMALS_HINT_PGI=_C('GL_BACK_NORMALS_HINT_PGI',0x1A223)
GL_CLIP_FAR_HINT_PGI=_C('GL_CLIP_FAR_HINT_PGI',0x1A221)
GL_CLIP_NEAR_HINT_PGI=_C('GL_CLIP_NEAR_HINT_PGI',0x1A220)
GL_CONSERVE_MEMORY_HINT_PGI=_C('GL_CONSERVE_MEMORY_HINT_PGI',0x1A1FD)
GL_FULL_STIPPLE_HINT_PGI=_C('GL_FULL_STIPPLE_HINT_PGI',0x1A219)
GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI=_C('GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI',0x1A203)
GL_NATIVE_GRAPHICS_END_HINT_PGI=_C('GL_NATIVE_GRAPHICS_END_HINT_PGI',0x1A204)
GL_NATIVE_GRAPHICS_HANDLE_PGI=_C('GL_NATIVE_GRAPHICS_HANDLE_PGI',0x1A202)
GL_PREFER_DOUBLEBUFFER_HINT_PGI=_C('GL_PREFER_DOUBLEBUFFER_HINT_PGI',0x1A1F8)
GL_RECLAIM_MEMORY_HINT_PGI=_C('GL_RECLAIM_MEMORY_HINT_PGI',0x1A1FE)
GL_STRICT_DEPTHFUNC_HINT_PGI=_C('GL_STRICT_DEPTHFUNC_HINT_PGI',0x1A216)
GL_STRICT_LIGHTING_HINT_PGI=_C('GL_STRICT_LIGHTING_HINT_PGI',0x1A217)
GL_STRICT_SCISSOR_HINT_PGI=_C('GL_STRICT_SCISSOR_HINT_PGI',0x1A218)
GL_WIDE_LINE_HINT_PGI=_C('GL_WIDE_LINE_HINT_PGI',0x1A222)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glHintPGI(target,mode):pass



'''OpenGL extension EXT.framebuffer_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.framebuffer_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the EXT_framebuffer_object framework to
	enable multisample rendering.
	
	The new operation RenderbufferStorageMultisampleEXT() allocates
	storage for a renderbuffer object that can be used as a multisample
	buffer.  A multisample render buffer image differs from a
	single-sample render buffer image in that a multisample image has a
	number of SAMPLES that is greater than zero.  No method is provided
	for creating multisample texture images.
	
	All of the framebuffer-attachable images attached to a framebuffer
	object must have the same number of SAMPLES or else the framebuffer
	object is not "framebuffer complete".  If a framebuffer object with
	multisample attachments is "framebuffer complete", then the
	framebuffer object behaves as if SAMPLE_BUFFERS is one.
	
	In traditional multisample rendering, where
	DRAW_FRAMEBUFFER_BINDING_EXT is zero and SAMPLE_BUFFERS is one, the
	GL spec states that "the color sample values are resolved to a
	single, displayable color each time a pixel is updated."  There are,
	however, several modern hardware implementations that do not
	actually resolve for each sample update, but instead postpones the
	resolve operation to a later time and resolve a batch of sample
	updates at a time.  This is OK as long as the implementation behaves
	"as if" it had resolved a sample-at-a-time. Unfortunately, however,
	honoring the "as if" rule can sometimes degrade performance.
	
	In contrast, when DRAW_FRAMEBUFFER_BINDING_EXT is an
	application-created framebuffer object, MULTISAMPLE is enabled, and
	SAMPLE_BUFFERS is one, there is no implicit per-sample-update
	resolve.  Instead, the application explicitly controls when the
	resolve operation is performed.  The resolve operation is affected
	by calling BlitFramebufferEXT (provided by the EXT_framebuffer_blit
	extension) where the source is a multisample application-created
	framebuffer object and the destination is a single-sample
	framebuffer object (either application-created or window-system
	provided).
	
	This design for multisample resolve more closely matches current
	hardware, but still permits implementations which choose to resolve
	a single sample at a time.  If hardware that implementes the
	multisample resolution "one sample at a time" exposes
	EXT_framebuffer_multisample, it could perform the implicit resolve
	to a driver-managed hidden surface, then read from that surface when
	the application calls BlitFramebufferEXT.
	
	Another motivation for granting the application explicit control
	over the multisample resolve operation has to do with the
	flexibility afforded by EXT_framebuffer_object.  Previously, a
	drawable (window or pbuffer) had exclusive access to all of its
	buffers.  There was no mechanism for sharing a buffer across
	multiple drawables.  Under EXT_framebuffer_object, however, a
	mechanism exists for sharing a framebuffer-attachable image across
	several framebuffer objects, as well as sharing an image between a
	framebuffer object and a texture.  If we had retained the "implicit"
	resolve from traditional multisampled rendering, and allowed the
	creation of "multisample" format renderbuffers, then this type of
	sharing would have lead to two problematic situations:
	
	  * Two contexts, which shared renderbuffers, might perform
	    competing resolve operations into the same single-sample buffer
	    with ambiguous results.
	
	  * It would have introduced the unfortunate ability to use the
	    single-sample buffer as a texture while MULTISAMPLE is ENABLED.
	
	By using the BlitFramebufferEXT from EXT_framebuffer_blit as an
	explicit resolve to serialize access to the multisampled contents
	and eliminate the implicit per-sample resolve operation, we avoid
	both of these problems.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/framebuffer_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.framebuffer_multisample import *
from OpenGL.raw.GL.EXT.framebuffer_multisample import _EXTENSION_NAME

def glInitFramebufferMultisampleEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OML.subsample

This module customises the behaviour of the 
OpenGL.raw.GL.OML.subsample to provide a more 
Python-friendly API

Overview (from the spec)
	
	Many video image formats and compression techniques utilize various
	component subsamplings, so it is necessary to provide a mechanism to
	specify the up- and down-sampling of components as pixel data is
	drawn from and read back to the client. Though subsampled components
	are normally associated with the video color space, YCrCb, use of
	subsampling in OpenGL does not imply a specific color space. Color
	space conversion may be performed using other extensions or core
	capabilities such as the color matrix.
	
	This extension defines two new pixel storage formats representing
	subsampled data on the client. It is loosely based on the
	SGIX_subsample extension, but specifies subsampling with the data
	format parameter rather than pixel packing parameters. It also
	adds support for CYA subsampled data.
	
	When pixel data is received from the client and an unpacking
	upsampling mode other than PIXEL_SUBSAMPLE_NONE_OML is specified,
	upsampling is performed via replication, unless otherwise specified
	by UNPACK_RESAMPLE_OML.
	
	Similarly, when pixel data is read back to the client and a packing
	downsampling mode other than PIXEL_SUBSAMPLE_NONE_OML is specified,
	downsampling is performed via simple component decimation (point
	sampling), unless otherwise specified by PACK_RESAMPLE_OML.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OML/subsample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OML.subsample import *
from OpenGL.raw.GL.OML.subsample import _EXTENSION_NAME

def glInitSubsampleOML():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
from OpenGL import images as _i
_i.COMPONENT_COUNTS[ GL_FORMAT_SUBSAMPLE_24_24_OML ] = 1 # must be GL_UNSIGNED_INT_10_10_10_2
_i.COMPONENT_COUNTS[ GL_FORMAT_SUBSAMPLE_244_244_OML ] = 1 # must be GL_UNSIGNED_INT_10_10_10_2



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_SGIX_video_resize'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_SGIX_video_resize',error_checker=_errors._error_checker)
GLX_SYNC_FRAME_SGIX=_C('GLX_SYNC_FRAME_SGIX',0x00000000)
GLX_SYNC_SWAP_SGIX=_C('GLX_SYNC_SWAP_SGIX',0x00000001)
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.Window)
def glXBindChannelToWindowSGIX(display,screen,channel,window):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int)
def glXChannelRectSGIX(display,screen,channel,x,y,w,h):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,_cs.GLenum)
def glXChannelRectSyncSGIX(display,screen,channel,synctype):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXQueryChannelDeltasSGIX(display,screen,channel,x,y,w,h):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXQueryChannelRectSGIX(display,screen,channel,dx,dy,dw,dh):pass



'''OpenGL extension MESA.set_3dfx_mode

This module customises the behaviour of the 
OpenGL.raw.GLX.MESA.set_3dfx_mode to provide a more 
Python-friendly API

Overview (from the spec)
	
	The Mesa Glide driver allows full-screen rendering or rendering into
	an X window.  The glXSet3DfxModeMESA() function allows an application
	to switch between full-screen and windowed rendering.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/set_3dfx_mode.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.MESA.set_3dfx_mode import *
from OpenGL.raw.GLX.MESA.set_3dfx_mode import _EXTENSION_NAME

def glInitSet3DfxModeMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_env_combine'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_env_combine',error_checker=_errors._error_checker)
GL_ADD_SIGNED_ARB=_C('GL_ADD_SIGNED_ARB',0x8574)
GL_COMBINE_ALPHA_ARB=_C('GL_COMBINE_ALPHA_ARB',0x8572)
GL_COMBINE_ARB=_C('GL_COMBINE_ARB',0x8570)
GL_COMBINE_RGB_ARB=_C('GL_COMBINE_RGB_ARB',0x8571)
GL_CONSTANT_ARB=_C('GL_CONSTANT_ARB',0x8576)
GL_INTERPOLATE_ARB=_C('GL_INTERPOLATE_ARB',0x8575)
GL_OPERAND0_ALPHA_ARB=_C('GL_OPERAND0_ALPHA_ARB',0x8598)
GL_OPERAND0_RGB_ARB=_C('GL_OPERAND0_RGB_ARB',0x8590)
GL_OPERAND1_ALPHA_ARB=_C('GL_OPERAND1_ALPHA_ARB',0x8599)
GL_OPERAND1_RGB_ARB=_C('GL_OPERAND1_RGB_ARB',0x8591)
GL_OPERAND2_ALPHA_ARB=_C('GL_OPERAND2_ALPHA_ARB',0x859A)
GL_OPERAND2_RGB_ARB=_C('GL_OPERAND2_RGB_ARB',0x8592)
GL_PREVIOUS_ARB=_C('GL_PREVIOUS_ARB',0x8578)
GL_PRIMARY_COLOR_ARB=_C('GL_PRIMARY_COLOR_ARB',0x8577)
GL_RGB_SCALE_ARB=_C('GL_RGB_SCALE_ARB',0x8573)
GL_SOURCE0_ALPHA_ARB=_C('GL_SOURCE0_ALPHA_ARB',0x8588)
GL_SOURCE0_RGB_ARB=_C('GL_SOURCE0_RGB_ARB',0x8580)
GL_SOURCE1_ALPHA_ARB=_C('GL_SOURCE1_ALPHA_ARB',0x8589)
GL_SOURCE1_RGB_ARB=_C('GL_SOURCE1_RGB_ARB',0x8581)
GL_SOURCE2_ALPHA_ARB=_C('GL_SOURCE2_ALPHA_ARB',0x858A)
GL_SOURCE2_RGB_ARB=_C('GL_SOURCE2_RGB_ARB',0x8582)
GL_SUBTRACT_ARB=_C('GL_SUBTRACT_ARB',0x84E7)




'''OpenGL extension ARB.texture_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new texture type, called a buffer texture.
	Buffer textures are one-dimensional arrays of texels whose storage comes
	from an attached buffer object.  When a buffer object is bound to a buffer
	texture, a format is specified, and the data in the buffer object is
	treated as an array of texels of the specified format.
	
	The use of a buffer object to provide storage allows the texture data to
	be specified in a number of different ways:  via buffer object loads
	(BufferData), direct CPU writes (MapBuffer), framebuffer readbacks
	(EXT_pixel_buffer_object extension).  A buffer object can also be loaded
	by transform feedback (NV_transform_feedback extension), which captures
	selected transformed attributes of vertices processed by the GL.  Several
	of these mechanisms do not require an extra data copy, which would be
	required when using conventional TexImage-like entry points.
	
	Buffer textures do not support mipmapping, texture lookups with normalized
	floating-point texture coordinates, and texture filtering of any sort, and
	may not be used in fixed-function fragment processing.  They can be
	accessed via single texel fetch operations in programmable shaders.  For
	assembly shaders (NV_gpu_program4), the TXF instruction is used.  For GLSL
	(EXT_gpu_shader4), a new sampler type and texel fetch function are used.
	
	While buffer textures can be substantially larger than equivalent
	one-dimensional textures; the maximum texture size supported for buffer
	textures in the initial implementation of this extension is 2^27 texels,
	versus 2^13 (8192) texels for otherwise equivalent one-dimensional
	textures.  When a buffer object is attached to a buffer texture, a size is
	not specified; rather, the number of texels in the texture is taken by
	dividing the size of the buffer object by the size of each texel.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_buffer_object import *
from OpenGL.raw.GL.ARB.texture_buffer_object import _EXTENSION_NAME

def glInitTextureBufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_vertex_program_evaluators'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_vertex_program_evaluators',error_checker=_errors._error_checker)
GL_VERTEX_ATTRIB_MAP1_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_APPLE',0x8A00)
GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_COEFF_APPLE',0x8A03)
GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_DOMAIN_APPLE',0x8A05)
GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_ORDER_APPLE',0x8A04)
GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE=_C('GL_VERTEX_ATTRIB_MAP1_SIZE_APPLE',0x8A02)
GL_VERTEX_ATTRIB_MAP2_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_APPLE',0x8A01)
GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_COEFF_APPLE',0x8A07)
GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_DOMAIN_APPLE',0x8A09)
GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_ORDER_APPLE',0x8A08)
GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE=_C('GL_VERTEX_ATTRIB_MAP2_SIZE_APPLE',0x8A06)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glDisableVertexAttribAPPLE(index,pname):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glEnableVertexAttribAPPLE(index,pname):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint,_cs.GLenum)
def glIsVertexAttribEnabledAPPLE(index,pname):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMapVertexAttrib1dAPPLE(index,size,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMapVertexAttrib1fAPPLE(index,size,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMapVertexAttrib2dAPPLE(index,size,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMapVertexAttrib2fAPPLE(index,size,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass



'''OpenGL extension APPLE.row_bytes

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.row_bytes to provide a more 
Python-friendly API

Overview (from the spec)
	
	The APPLE_row_bytes extension was developed to relax the limitations
	within GL regarding the packing and unpacking of pixel data from
	arbitrary arrangements in memory.
	
	Prior to this extension, similar, albeit more restrictive, functionality
	existed in GL using pixel storage modes for unpacking, packing, and
	alignment.  The limitation of the existing mechanism lies primarily in how
	packing or unpacking of data is specified with pixel atomicity rather than
	basic machine units.  To some extent, this pixel granularity can be
	overcome using pixel storage modes GL_UNPACK_ALIGNMENT and
	GL_PACK_ALIGNMENT.  Both of these parameters are specified in basic
	machine units but their range of possible values is restricted and even
	then they do not allow for the packing and unpacking of pixel data in a
	fully arbitrary manner.
	
	Consider this simple example:
	
	    Consider a column of pixels in memory.  The pixels are of GL_RGB 
	    format and GL_UNSIGNED_BYTE type resulting in 3 bytes per pixel.
	    Now consider that this column of pixel data was arranged in memory
	    such that each row of the image (in this case each pixel) has two
	    bytes padding or space between them.
	
	    Each row of 1 pixel then has 5 bytes.  An attempting to express this
	    memory arrangement with existing pixel storage semantics would
	    naturally start with a GL_UNPACK_ROW_LENGTH of 1 because there is
	    one pixel per row.  However, no valid value of GL_UNPACK_ALIGNMENT,
	    1, 2, 4, or 8, will allow the proper row padding to express this 
	    memory arrangement.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/row_bytes.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.row_bytes import *
from OpenGL.raw.GL.APPLE.row_bytes import _EXTENSION_NAME

def glInitRowBytesAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_3_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_3_0',error_checker=_errors._error_checker)
GL_ALPHA_INTEGER=_C('GL_ALPHA_INTEGER',0x8D97)
GL_BGRA_INTEGER=_C('GL_BGRA_INTEGER',0x8D9B)
GL_BGR_INTEGER=_C('GL_BGR_INTEGER',0x8D9A)
GL_BLUE_INTEGER=_C('GL_BLUE_INTEGER',0x8D96)
GL_BUFFER_ACCESS_FLAGS=_C('GL_BUFFER_ACCESS_FLAGS',0x911F)
GL_BUFFER_MAP_LENGTH=_C('GL_BUFFER_MAP_LENGTH',0x9120)
GL_BUFFER_MAP_OFFSET=_C('GL_BUFFER_MAP_OFFSET',0x9121)
GL_CLAMP_FRAGMENT_COLOR=_C('GL_CLAMP_FRAGMENT_COLOR',0x891B)
GL_CLAMP_READ_COLOR=_C('GL_CLAMP_READ_COLOR',0x891C)
GL_CLAMP_VERTEX_COLOR=_C('GL_CLAMP_VERTEX_COLOR',0x891A)
GL_CLIP_DISTANCE0=_C('GL_CLIP_DISTANCE0',0x3000)
GL_CLIP_DISTANCE1=_C('GL_CLIP_DISTANCE1',0x3001)
GL_CLIP_DISTANCE2=_C('GL_CLIP_DISTANCE2',0x3002)
GL_CLIP_DISTANCE3=_C('GL_CLIP_DISTANCE3',0x3003)
GL_CLIP_DISTANCE4=_C('GL_CLIP_DISTANCE4',0x3004)
GL_CLIP_DISTANCE5=_C('GL_CLIP_DISTANCE5',0x3005)
GL_CLIP_DISTANCE6=_C('GL_CLIP_DISTANCE6',0x3006)
GL_CLIP_DISTANCE7=_C('GL_CLIP_DISTANCE7',0x3007)
GL_COLOR_ATTACHMENT0=_C('GL_COLOR_ATTACHMENT0',0x8CE0)
GL_COLOR_ATTACHMENT1=_C('GL_COLOR_ATTACHMENT1',0x8CE1)
GL_COLOR_ATTACHMENT10=_C('GL_COLOR_ATTACHMENT10',0x8CEA)
GL_COLOR_ATTACHMENT11=_C('GL_COLOR_ATTACHMENT11',0x8CEB)
GL_COLOR_ATTACHMENT12=_C('GL_COLOR_ATTACHMENT12',0x8CEC)
GL_COLOR_ATTACHMENT13=_C('GL_COLOR_ATTACHMENT13',0x8CED)
GL_COLOR_ATTACHMENT14=_C('GL_COLOR_ATTACHMENT14',0x8CEE)
GL_COLOR_ATTACHMENT15=_C('GL_COLOR_ATTACHMENT15',0x8CEF)
GL_COLOR_ATTACHMENT2=_C('GL_COLOR_ATTACHMENT2',0x8CE2)
GL_COLOR_ATTACHMENT3=_C('GL_COLOR_ATTACHMENT3',0x8CE3)
GL_COLOR_ATTACHMENT4=_C('GL_COLOR_ATTACHMENT4',0x8CE4)
GL_COLOR_ATTACHMENT5=_C('GL_COLOR_ATTACHMENT5',0x8CE5)
GL_COLOR_ATTACHMENT6=_C('GL_COLOR_ATTACHMENT6',0x8CE6)
GL_COLOR_ATTACHMENT7=_C('GL_COLOR_ATTACHMENT7',0x8CE7)
GL_COLOR_ATTACHMENT8=_C('GL_COLOR_ATTACHMENT8',0x8CE8)
GL_COLOR_ATTACHMENT9=_C('GL_COLOR_ATTACHMENT9',0x8CE9)
GL_COMPARE_REF_TO_TEXTURE=_C('GL_COMPARE_REF_TO_TEXTURE',0x884E)
GL_COMPRESSED_RED=_C('GL_COMPRESSED_RED',0x8225)
GL_COMPRESSED_RED_RGTC1=_C('GL_COMPRESSED_RED_RGTC1',0x8DBB)
GL_COMPRESSED_RG=_C('GL_COMPRESSED_RG',0x8226)
GL_COMPRESSED_RG_RGTC2=_C('GL_COMPRESSED_RG_RGTC2',0x8DBD)
GL_COMPRESSED_SIGNED_RED_RGTC1=_C('GL_COMPRESSED_SIGNED_RED_RGTC1',0x8DBC)
GL_COMPRESSED_SIGNED_RG_RGTC2=_C('GL_COMPRESSED_SIGNED_RG_RGTC2',0x8DBE)
GL_CONTEXT_FLAGS=_C('GL_CONTEXT_FLAGS',0x821E)
GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT=_C('GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT',0x00000001)
GL_DEPTH24_STENCIL8=_C('GL_DEPTH24_STENCIL8',0x88F0)
GL_DEPTH32F_STENCIL8=_C('GL_DEPTH32F_STENCIL8',0x8CAD)
GL_DEPTH_ATTACHMENT=_C('GL_DEPTH_ATTACHMENT',0x8D00)
GL_DEPTH_COMPONENT32F=_C('GL_DEPTH_COMPONENT32F',0x8CAC)
GL_DEPTH_STENCIL=_C('GL_DEPTH_STENCIL',0x84F9)
GL_DEPTH_STENCIL_ATTACHMENT=_C('GL_DEPTH_STENCIL_ATTACHMENT',0x821A)
GL_DRAW_FRAMEBUFFER=_C('GL_DRAW_FRAMEBUFFER',0x8CA9)
GL_DRAW_FRAMEBUFFER_BINDING=_C('GL_DRAW_FRAMEBUFFER_BINDING',0x8CA6)
GL_FIXED_ONLY=_C('GL_FIXED_ONLY',0x891D)
GL_FLOAT_32_UNSIGNED_INT_24_8_REV=_C('GL_FLOAT_32_UNSIGNED_INT_24_8_REV',0x8DAD)
GL_FRAMEBUFFER=_C('GL_FRAMEBUFFER',0x8D40)
GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE',0x8215)
GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE',0x8214)
GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING=_C('GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING',0x8210)
GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE=_C('GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE',0x8211)
GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE',0x8216)
GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE',0x8213)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME',0x8CD1)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE',0x8CD0)
GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE',0x8212)
GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE',0x8217)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE',0x8CD3)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER',0x8CD4)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL',0x8CD2)
GL_FRAMEBUFFER_BINDING=_C('GL_FRAMEBUFFER_BINDING',0x8CA6)
GL_FRAMEBUFFER_COMPLETE=_C('GL_FRAMEBUFFER_COMPLETE',0x8CD5)
GL_FRAMEBUFFER_DEFAULT=_C('GL_FRAMEBUFFER_DEFAULT',0x8218)
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT=_C('GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT',0x8CD6)
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER=_C('GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER',0x8CDB)
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT=_C('GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT',0x8CD7)
GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE=_C('GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE',0x8D56)
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER=_C('GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER',0x8CDC)
GL_FRAMEBUFFER_SRGB=_C('GL_FRAMEBUFFER_SRGB',0x8DB9)
GL_FRAMEBUFFER_UNDEFINED=_C('GL_FRAMEBUFFER_UNDEFINED',0x8219)
GL_FRAMEBUFFER_UNSUPPORTED=_C('GL_FRAMEBUFFER_UNSUPPORTED',0x8CDD)
GL_GREEN_INTEGER=_C('GL_GREEN_INTEGER',0x8D95)
GL_HALF_FLOAT=_C('GL_HALF_FLOAT',0x140B)
GL_INDEX=_C('GL_INDEX',0x8222)
GL_INTERLEAVED_ATTRIBS=_C('GL_INTERLEAVED_ATTRIBS',0x8C8C)
GL_INT_SAMPLER_1D=_C('GL_INT_SAMPLER_1D',0x8DC9)
GL_INT_SAMPLER_1D_ARRAY=_C('GL_INT_SAMPLER_1D_ARRAY',0x8DCE)
GL_INT_SAMPLER_2D=_C('GL_INT_SAMPLER_2D',0x8DCA)
GL_INT_SAMPLER_2D_ARRAY=_C('GL_INT_SAMPLER_2D_ARRAY',0x8DCF)
GL_INT_SAMPLER_3D=_C('GL_INT_SAMPLER_3D',0x8DCB)
GL_INT_SAMPLER_CUBE=_C('GL_INT_SAMPLER_CUBE',0x8DCC)
GL_INVALID_FRAMEBUFFER_OPERATION=_C('GL_INVALID_FRAMEBUFFER_OPERATION',0x0506)
GL_MAJOR_VERSION=_C('GL_MAJOR_VERSION',0x821B)
GL_MAP_FLUSH_EXPLICIT_BIT=_C('GL_MAP_FLUSH_EXPLICIT_BIT',0x0010)
GL_MAP_INVALIDATE_BUFFER_BIT=_C('GL_MAP_INVALIDATE_BUFFER_BIT',0x0008)
GL_MAP_INVALIDATE_RANGE_BIT=_C('GL_MAP_INVALIDATE_RANGE_BIT',0x0004)
GL_MAP_READ_BIT=_C('GL_MAP_READ_BIT',0x0001)
GL_MAP_UNSYNCHRONIZED_BIT=_C('GL_MAP_UNSYNCHRONIZED_BIT',0x0020)
GL_MAP_WRITE_BIT=_C('GL_MAP_WRITE_BIT',0x0002)
GL_MAX_ARRAY_TEXTURE_LAYERS=_C('GL_MAX_ARRAY_TEXTURE_LAYERS',0x88FF)
GL_MAX_CLIP_DISTANCES=_C('GL_MAX_CLIP_DISTANCES',0x0D32)
GL_MAX_COLOR_ATTACHMENTS=_C('GL_MAX_COLOR_ATTACHMENTS',0x8CDF)
GL_MAX_PROGRAM_TEXEL_OFFSET=_C('GL_MAX_PROGRAM_TEXEL_OFFSET',0x8905)
GL_MAX_RENDERBUFFER_SIZE=_C('GL_MAX_RENDERBUFFER_SIZE',0x84E8)
GL_MAX_SAMPLES=_C('GL_MAX_SAMPLES',0x8D57)
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS=_C('GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS',0x8C8A)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS',0x8C8B)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS',0x8C80)
GL_MAX_VARYING_COMPONENTS=_C('GL_MAX_VARYING_COMPONENTS',0x8B4B)
GL_MINOR_VERSION=_C('GL_MINOR_VERSION',0x821C)
GL_MIN_PROGRAM_TEXEL_OFFSET=_C('GL_MIN_PROGRAM_TEXEL_OFFSET',0x8904)
GL_NUM_EXTENSIONS=_C('GL_NUM_EXTENSIONS',0x821D)
GL_PRIMITIVES_GENERATED=_C('GL_PRIMITIVES_GENERATED',0x8C87)
GL_PROXY_TEXTURE_1D_ARRAY=_C('GL_PROXY_TEXTURE_1D_ARRAY',0x8C19)
GL_PROXY_TEXTURE_2D_ARRAY=_C('GL_PROXY_TEXTURE_2D_ARRAY',0x8C1B)
GL_QUERY_BY_REGION_NO_WAIT=_C('GL_QUERY_BY_REGION_NO_WAIT',0x8E16)
GL_QUERY_BY_REGION_WAIT=_C('GL_QUERY_BY_REGION_WAIT',0x8E15)
GL_QUERY_NO_WAIT=_C('GL_QUERY_NO_WAIT',0x8E14)
GL_QUERY_WAIT=_C('GL_QUERY_WAIT',0x8E13)
GL_R11F_G11F_B10F=_C('GL_R11F_G11F_B10F',0x8C3A)
GL_R16=_C('GL_R16',0x822A)
GL_R16F=_C('GL_R16F',0x822D)
GL_R16I=_C('GL_R16I',0x8233)
GL_R16UI=_C('GL_R16UI',0x8234)
GL_R32F=_C('GL_R32F',0x822E)
GL_R32I=_C('GL_R32I',0x8235)
GL_R32UI=_C('GL_R32UI',0x8236)
GL_R8=_C('GL_R8',0x8229)
GL_R8I=_C('GL_R8I',0x8231)
GL_R8UI=_C('GL_R8UI',0x8232)
GL_RASTERIZER_DISCARD=_C('GL_RASTERIZER_DISCARD',0x8C89)
GL_READ_FRAMEBUFFER=_C('GL_READ_FRAMEBUFFER',0x8CA8)
GL_READ_FRAMEBUFFER_BINDING=_C('GL_READ_FRAMEBUFFER_BINDING',0x8CAA)
GL_RED_INTEGER=_C('GL_RED_INTEGER',0x8D94)
GL_RENDERBUFFER=_C('GL_RENDERBUFFER',0x8D41)
GL_RENDERBUFFER_ALPHA_SIZE=_C('GL_RENDERBUFFER_ALPHA_SIZE',0x8D53)
GL_RENDERBUFFER_BINDING=_C('GL_RENDERBUFFER_BINDING',0x8CA7)
GL_RENDERBUFFER_BLUE_SIZE=_C('GL_RENDERBUFFER_BLUE_SIZE',0x8D52)
GL_RENDERBUFFER_DEPTH_SIZE=_C('GL_RENDERBUFFER_DEPTH_SIZE',0x8D54)
GL_RENDERBUFFER_GREEN_SIZE=_C('GL_RENDERBUFFER_GREEN_SIZE',0x8D51)
GL_RENDERBUFFER_HEIGHT=_C('GL_RENDERBUFFER_HEIGHT',0x8D43)
GL_RENDERBUFFER_INTERNAL_FORMAT=_C('GL_RENDERBUFFER_INTERNAL_FORMAT',0x8D44)
GL_RENDERBUFFER_RED_SIZE=_C('GL_RENDERBUFFER_RED_SIZE',0x8D50)
GL_RENDERBUFFER_SAMPLES=_C('GL_RENDERBUFFER_SAMPLES',0x8CAB)
GL_RENDERBUFFER_STENCIL_SIZE=_C('GL_RENDERBUFFER_STENCIL_SIZE',0x8D55)
GL_RENDERBUFFER_WIDTH=_C('GL_RENDERBUFFER_WIDTH',0x8D42)
GL_RG=_C('GL_RG',0x8227)
GL_RG16=_C('GL_RG16',0x822C)
GL_RG16F=_C('GL_RG16F',0x822F)
GL_RG16I=_C('GL_RG16I',0x8239)
GL_RG16UI=_C('GL_RG16UI',0x823A)
GL_RG32F=_C('GL_RG32F',0x8230)
GL_RG32I=_C('GL_RG32I',0x823B)
GL_RG32UI=_C('GL_RG32UI',0x823C)
GL_RG8=_C('GL_RG8',0x822B)
GL_RG8I=_C('GL_RG8I',0x8237)
GL_RG8UI=_C('GL_RG8UI',0x8238)
GL_RGB16F=_C('GL_RGB16F',0x881B)
GL_RGB16I=_C('GL_RGB16I',0x8D89)
GL_RGB16UI=_C('GL_RGB16UI',0x8D77)
GL_RGB32F=_C('GL_RGB32F',0x8815)
GL_RGB32I=_C('GL_RGB32I',0x8D83)
GL_RGB32UI=_C('GL_RGB32UI',0x8D71)
GL_RGB8I=_C('GL_RGB8I',0x8D8F)
GL_RGB8UI=_C('GL_RGB8UI',0x8D7D)
GL_RGB9_E5=_C('GL_RGB9_E5',0x8C3D)
GL_RGBA16F=_C('GL_RGBA16F',0x881A)
GL_RGBA16I=_C('GL_RGBA16I',0x8D88)
GL_RGBA16UI=_C('GL_RGBA16UI',0x8D76)
GL_RGBA32F=_C('GL_RGBA32F',0x8814)
GL_RGBA32I=_C('GL_RGBA32I',0x8D82)
GL_RGBA32UI=_C('GL_RGBA32UI',0x8D70)
GL_RGBA8I=_C('GL_RGBA8I',0x8D8E)
GL_RGBA8UI=_C('GL_RGBA8UI',0x8D7C)
GL_RGBA_INTEGER=_C('GL_RGBA_INTEGER',0x8D99)
GL_RGB_INTEGER=_C('GL_RGB_INTEGER',0x8D98)
GL_RG_INTEGER=_C('GL_RG_INTEGER',0x8228)
GL_SAMPLER_1D_ARRAY=_C('GL_SAMPLER_1D_ARRAY',0x8DC0)
GL_SAMPLER_1D_ARRAY_SHADOW=_C('GL_SAMPLER_1D_ARRAY_SHADOW',0x8DC3)
GL_SAMPLER_2D_ARRAY=_C('GL_SAMPLER_2D_ARRAY',0x8DC1)
GL_SAMPLER_2D_ARRAY_SHADOW=_C('GL_SAMPLER_2D_ARRAY_SHADOW',0x8DC4)
GL_SAMPLER_CUBE_SHADOW=_C('GL_SAMPLER_CUBE_SHADOW',0x8DC5)
GL_SEPARATE_ATTRIBS=_C('GL_SEPARATE_ATTRIBS',0x8C8D)
GL_STENCIL_ATTACHMENT=_C('GL_STENCIL_ATTACHMENT',0x8D20)
GL_STENCIL_INDEX1=_C('GL_STENCIL_INDEX1',0x8D46)
GL_STENCIL_INDEX16=_C('GL_STENCIL_INDEX16',0x8D49)
GL_STENCIL_INDEX4=_C('GL_STENCIL_INDEX4',0x8D47)
GL_STENCIL_INDEX8=_C('GL_STENCIL_INDEX8',0x8D48)
GL_TEXTURE_1D_ARRAY=_C('GL_TEXTURE_1D_ARRAY',0x8C18)
GL_TEXTURE_2D_ARRAY=_C('GL_TEXTURE_2D_ARRAY',0x8C1A)
GL_TEXTURE_ALPHA_TYPE=_C('GL_TEXTURE_ALPHA_TYPE',0x8C13)
GL_TEXTURE_BINDING_1D_ARRAY=_C('GL_TEXTURE_BINDING_1D_ARRAY',0x8C1C)
GL_TEXTURE_BINDING_2D_ARRAY=_C('GL_TEXTURE_BINDING_2D_ARRAY',0x8C1D)
GL_TEXTURE_BLUE_TYPE=_C('GL_TEXTURE_BLUE_TYPE',0x8C12)
GL_TEXTURE_DEPTH_TYPE=_C('GL_TEXTURE_DEPTH_TYPE',0x8C16)
GL_TEXTURE_GREEN_TYPE=_C('GL_TEXTURE_GREEN_TYPE',0x8C11)
GL_TEXTURE_INTENSITY_TYPE=_C('GL_TEXTURE_INTENSITY_TYPE',0x8C15)
GL_TEXTURE_LUMINANCE_TYPE=_C('GL_TEXTURE_LUMINANCE_TYPE',0x8C14)
GL_TEXTURE_RED_TYPE=_C('GL_TEXTURE_RED_TYPE',0x8C10)
GL_TEXTURE_SHARED_SIZE=_C('GL_TEXTURE_SHARED_SIZE',0x8C3F)
GL_TEXTURE_STENCIL_SIZE=_C('GL_TEXTURE_STENCIL_SIZE',0x88F1)
GL_TRANSFORM_FEEDBACK_BUFFER=_C('GL_TRANSFORM_FEEDBACK_BUFFER',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING=_C('GL_TRANSFORM_FEEDBACK_BUFFER_BINDING',0x8C8F)
GL_TRANSFORM_FEEDBACK_BUFFER_MODE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_MODE',0x8C7F)
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_SIZE',0x8C85)
GL_TRANSFORM_FEEDBACK_BUFFER_START=_C('GL_TRANSFORM_FEEDBACK_BUFFER_START',0x8C84)
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN=_C('GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN',0x8C88)
GL_TRANSFORM_FEEDBACK_VARYINGS=_C('GL_TRANSFORM_FEEDBACK_VARYINGS',0x8C83)
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH=_C('GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH',0x8C76)
GL_UNSIGNED_INT_10F_11F_11F_REV=_C('GL_UNSIGNED_INT_10F_11F_11F_REV',0x8C3B)
GL_UNSIGNED_INT_24_8=_C('GL_UNSIGNED_INT_24_8',0x84FA)
GL_UNSIGNED_INT_5_9_9_9_REV=_C('GL_UNSIGNED_INT_5_9_9_9_REV',0x8C3E)
GL_UNSIGNED_INT_SAMPLER_1D=_C('GL_UNSIGNED_INT_SAMPLER_1D',0x8DD1)
GL_UNSIGNED_INT_SAMPLER_1D_ARRAY=_C('GL_UNSIGNED_INT_SAMPLER_1D_ARRAY',0x8DD6)
GL_UNSIGNED_INT_SAMPLER_2D=_C('GL_UNSIGNED_INT_SAMPLER_2D',0x8DD2)
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY=_C('GL_UNSIGNED_INT_SAMPLER_2D_ARRAY',0x8DD7)
GL_UNSIGNED_INT_SAMPLER_3D=_C('GL_UNSIGNED_INT_SAMPLER_3D',0x8DD3)
GL_UNSIGNED_INT_SAMPLER_CUBE=_C('GL_UNSIGNED_INT_SAMPLER_CUBE',0x8DD4)
GL_UNSIGNED_INT_VEC2=_C('GL_UNSIGNED_INT_VEC2',0x8DC6)
GL_UNSIGNED_INT_VEC3=_C('GL_UNSIGNED_INT_VEC3',0x8DC7)
GL_UNSIGNED_INT_VEC4=_C('GL_UNSIGNED_INT_VEC4',0x8DC8)
GL_UNSIGNED_NORMALIZED=_C('GL_UNSIGNED_NORMALIZED',0x8C17)
GL_VERTEX_ARRAY_BINDING=_C('GL_VERTEX_ARRAY_BINDING',0x85B5)
GL_VERTEX_ATTRIB_ARRAY_INTEGER=_C('GL_VERTEX_ATTRIB_ARRAY_INTEGER',0x88FD)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glBeginConditionalRender(id,mode):pass
@_f
@_p.types(None,_cs.GLenum)
def glBeginTransformFeedback(primitiveMode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glBindBufferBase(target,index,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glBindBufferRange(target,index,buffer,offset,size):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glBindFragDataLocation(program,color,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindFramebuffer(target,framebuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindRenderbuffer(target,renderbuffer):pass
@_f
@_p.types(None,_cs.GLuint)
def glBindVertexArray(array):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glBlitFramebuffer(srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum)
def glCheckFramebufferStatus(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glClampColor(target,clamp):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLfloat,_cs.GLint)
def glClearBufferfi(buffer,drawbuffer,depth,stencil):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLfloatArray)
def glClearBufferfv(buffer,drawbuffer,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLintArray)
def glClearBufferiv(buffer,drawbuffer,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLuintArray)
def glClearBufferuiv(buffer,drawbuffer,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean)
def glColorMaski(index,r,g,b,a):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteFramebuffers(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteRenderbuffers(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteVertexArrays(n,arrays):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glDisablei(target,index):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glEnablei(target,index):pass
@_f
@_p.types(None,)
def glEndConditionalRender():pass
@_f
@_p.types(None,)
def glEndTransformFeedback():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr)
def glFlushMappedBufferRange(target,offset,length):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glFramebufferRenderbuffer(target,attachment,renderbuffertarget,renderbuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture1D(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture2D(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTexture3D(target,attachment,textarget,texture,level,zoffset):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTextureLayer(target,attachment,texture,level,layer):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenFramebuffers(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenRenderbuffers(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenVertexArrays(n,arrays):pass
@_f
@_p.types(None,_cs.GLenum)
def glGenerateMipmap(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLbooleanArray)
def glGetBooleani_v(target,index,data):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetFragDataLocation(program,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFramebufferAttachmentParameteriv(target,attachment,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLintArray)
def glGetIntegeri_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetRenderbufferParameteriv(target,pname,params):pass
@_f
@_p.types(arrays.GLubyteArray,_cs.GLenum,_cs.GLuint)
def glGetStringi(name,index):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexParameterIiv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glGetTexParameterIuiv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray)
def glGetTransformFeedbackVarying(program,index,bufSize,length,size,type,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,arrays.GLuintArray)
def glGetUniformuiv(program,location,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribIiv(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetVertexAttribIuiv(index,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum,_cs.GLuint)
def glIsEnabledi(target,index):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsFramebuffer(framebuffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsRenderbuffer(renderbuffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsVertexArray(array):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLbitfield)
def glMapBufferRange(target,offset,length,access):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorage(target,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorageMultisample(target,samples,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexParameterIiv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glTexParameterIuiv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),_cs.GLenum)
def glTransformFeedbackVaryings(program,count,varyings,bufferMode):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint)
def glUniform1ui(location,v0):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform1uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint)
def glUniform2ui(location,v0,v1):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform2uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform3ui(location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform3uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform4ui(location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform4uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint)
def glVertexAttribI1i(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI1iv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribI1ui(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI1uiv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint)
def glVertexAttribI2i(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI2iv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI2ui(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI2uiv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertexAttribI3i(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI3iv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI3ui(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI3uiv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttribI4bv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertexAttribI4i(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI4iv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttribI4sv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttribI4ubv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI4ui(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI4uiv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttribI4usv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribIPointer(index,size,type,stride,pointer):pass
